[Checkins] SVN: PluggableAuthService/trunk/plugins/BasePlugin.py Shut up DeprecationWarning: isImplementedBy has been renamed to providedBy.

Stefan H. Holek stefan at epy.co.at
Sun Jul 8 12:27:57 EDT 2007


Log message for revision 77631:
  Shut up DeprecationWarning: isImplementedBy has been renamed to providedBy.
  

Changed:
  U   PluggableAuthService/trunk/plugins/BasePlugin.py

-=-
Modified: PluggableAuthService/trunk/plugins/BasePlugin.py
===================================================================
--- PluggableAuthService/trunk/plugins/BasePlugin.py	2007-07-08 16:17:58 UTC (rev 77630)
+++ PluggableAuthService/trunk/plugins/BasePlugin.py	2007-07-08 16:27:57 UTC (rev 77631)
@@ -70,8 +70,8 @@
 
     security.declareProtected( ManageUsers, 'testImplements' )
     def testImplements( self, interface ):
-        """ Can't access Interface.isImplementedBy() directly in ZPT. """
-        return interface.isImplementedBy( self )
+        """ Can't access Interface.providedBy() directly in ZPT. """
+        return interface.providedBy( self )
 
     security.declareProtected( ManageUsers, 'manage_activateInterfaces' )
     def manage_activateInterfaces( self, interfaces, RESPONSE=None ):



More information about the Checkins mailing list